.. Graph Scheduler documentation master file, created by
   sphinx-quickstart on Tue Jul  6 22:15:43 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   self
   Scheduler
   Condition
   Time

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
